package Paws::AutoScaling::LaunchConfiguration;
  use Moose;
  has AssociatePublicIpAddress => (is => 'ro', isa => 'Bool');
  has BlockDeviceMappings => (is => 'ro', isa => 'ArrayRef[Paws::AutoScaling::BlockDeviceMapping]');
  has ClassicLinkVPCId => (is => 'ro', isa => 'Str');
  has ClassicLinkVPCSecurityGroups => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has CreatedTime => (is => 'ro', isa => 'Str', required => 1);
  has EbsOptimized => (is => 'ro', isa => 'Bool');
  has IamInstanceProfile => (is => 'ro', isa => 'Str');
  has ImageId => (is => 'ro', isa => 'Str', required => 1);
  has InstanceMonitoring => (is => 'ro', isa => 'Paws::AutoScaling::InstanceMonitoring');
  has InstanceType => (is => 'ro', isa => 'Str', required => 1);
  has KernelId => (is => 'ro', isa => 'Str');
  has KeyName => (is => 'ro', isa => 'Str');
  has LaunchConfigurationARN => (is => 'ro', isa => 'Str');
  has LaunchConfigurationName => (is => 'ro', isa => 'Str', required => 1);
  has PlacementTenancy => (is => 'ro', isa => 'Str');
  has RamdiskId => (is => 'ro', isa => 'Str');
  has SecurityGroups => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has SpotPrice => (is => 'ro', isa => 'Str');
  has UserData => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::LaunchConfiguration

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AutoScaling::LaunchConfiguration object:

  $service_obj->Method(Att1 => { AssociatePublicIpAddress => $value, ..., UserData => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AutoScaling::LaunchConfiguration object:

  $result = $service_obj->Method(...);
  $result->Att1->AssociatePublicIpAddress

=head1 DESCRIPTION

Describes a launch configuration.

=head1 ATTRIBUTES


=head2 AssociatePublicIpAddress => Bool

  For Auto Scaling groups that are running in a VPC, specifies whether to
assign a public IP address to the group's instances.

For more information, see Launching Auto Scaling Instances in a VPC
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-in-vpc.html)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 BlockDeviceMappings => ArrayRef[L<Paws::AutoScaling::BlockDeviceMapping>]

  A block device mapping, which specifies the block devices for the
instance.

For more information, see Block Device Mapping
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/block-device-mapping-concepts.html)
in the I<Amazon EC2 User Guide for Linux Instances>.


=head2 ClassicLinkVPCId => Str

  The ID of a ClassicLink-enabled VPC to link your EC2-Classic instances
to.

For more information, see ClassicLink
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html)
in the I<Amazon EC2 User Guide for Linux Instances> and Linking
EC2-Classic Instances to a VPC
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-in-vpc.html#as-ClassicLink)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 ClassicLinkVPCSecurityGroups => ArrayRef[Str|Undef]

  The IDs of one or more security groups for the VPC specified in
C<ClassicLinkVPCId>.

For more information, see ClassicLink
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-classiclink.html)
in the I<Amazon EC2 User Guide for Linux Instances> and Linking
EC2-Classic Instances to a VPC
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-in-vpc.html#as-ClassicLink)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 B<REQUIRED> CreatedTime => Str

  The creation date and time for the launch configuration.


=head2 EbsOptimized => Bool

  Specifies whether the launch configuration is optimized for EBS I/O
(C<true>) or not (C<false>).

For more information, see Amazon EBS-Optimized Instances
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html)
in the I<Amazon EC2 User Guide for Linux Instances>.


=head2 IamInstanceProfile => Str

  The name or the Amazon Resource Name (ARN) of the instance profile
associated with the IAM role for the instance. The instance profile
contains the IAM role.

For more information, see IAM Role for Applications That Run on Amazon
EC2 Instances
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/us-iam-role.html)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 B<REQUIRED> ImageId => Str

  The ID of the Amazon Machine Image (AMI) to use to launch your EC2
instances.

For more information, see Finding an AMI
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/finding-an-ami.html)
in the I<Amazon EC2 User Guide for Linux Instances>.


=head2 InstanceMonitoring => L<Paws::AutoScaling::InstanceMonitoring>

  Controls whether instances in this group are launched with detailed
(C<true>) or basic (C<false>) monitoring.

For more information, see Configure Monitoring for Auto Scaling
Instances
(https://docs.aws.amazon.com/autoscaling/latest/userguide/as-instance-monitoring.html#enable-as-instance-metrics)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 B<REQUIRED> InstanceType => Str

  The instance type for the instances.

For information about available instance types, see Available Instance
Types
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#AvailableInstanceTypes)
in the I<Amazon EC2 User Guide for Linux Instances.>


=head2 KernelId => Str

  The ID of the kernel associated with the AMI.


=head2 KeyName => Str

  The name of the key pair.

For more information, see Amazon EC2 Key Pairs
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html)
in the I<Amazon EC2 User Guide for Linux Instances>.


=head2 LaunchConfigurationARN => Str

  The Amazon Resource Name (ARN) of the launch configuration.


=head2 B<REQUIRED> LaunchConfigurationName => Str

  The name of the launch configuration.


=head2 PlacementTenancy => Str

  The tenancy of the instance, either C<default> or C<dedicated>. An
instance with C<dedicated> tenancy runs on isolated, single-tenant
hardware and can only be launched into a VPC.

For more information, see Instance Placement Tenancy
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-in-vpc.html#as-vpc-tenancy)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 RamdiskId => Str

  The ID of the RAM disk associated with the AMI.


=head2 SecurityGroups => ArrayRef[Str|Undef]

  A list that contains the security groups to assign to the instances in
the Auto Scaling group.

For more information, see Security Groups for Your VPC
(https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_SecurityGroups.html)
in the I<Amazon Virtual Private Cloud User Guide>.


=head2 SpotPrice => Str

  The maximum hourly price to be paid for any Spot Instance launched to
fulfill the request. Spot Instances are launched when the price you
specify exceeds the current Spot price.

For more information, see Launching Spot Instances in Your Auto Scaling
Group
(https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-launch-spot-instances.html)
in the I<Amazon EC2 Auto Scaling User Guide>.


=head2 UserData => Str

  The Base64-encoded user data to make available to the launched EC2
instances.

For more information, see Instance Metadata and User Data
(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-metadata.html)
in the I<Amazon EC2 User Guide for Linux Instances>.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AutoScaling>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

