
package Paws::Pinpoint::GetUserEndpoints;
  use Moose;
  has ApplicationId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'application-id', required => 1);
  has UserId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'user-id', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetUserEndpoints');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/v1/apps/{application-id}/users/{user-id}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Pinpoint::GetUserEndpointsResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Pinpoint::GetUserEndpoints - Arguments for method GetUserEndpoints on L<Paws::Pinpoint>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetUserEndpoints on the
L<Amazon Pinpoint|Paws::Pinpoint> service. Use the attributes of this class
as arguments to method GetUserEndpoints.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetUserEndpoints.

=head1 SYNOPSIS

    my $pinpoint = Paws->service('Pinpoint');
    my $GetUserEndpointsResponse = $pinpoint->GetUserEndpoints(
      ApplicationId => 'My__string',
      UserId        => 'My__string',

    );

    # Results:
    my $EndpointsResponse = $GetUserEndpointsResponse->EndpointsResponse;

    # Returns a L<Paws::Pinpoint::GetUserEndpointsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/pinpoint/GetUserEndpoints>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ApplicationId => Str

The unique identifier for the application. This identifier is displayed
as the B<Project ID> on the Amazon Pinpoint console.



=head2 B<REQUIRED> UserId => Str

The unique identifier for the user.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetUserEndpoints in L<Paws::Pinpoint>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

