
package Paws::Transfer::UpdateServer;
  use Moose;
  has EndpointDetails => (is => 'ro', isa => 'Paws::Transfer::EndpointDetails');
  has EndpointType => (is => 'ro', isa => 'Str');
  has HostKey => (is => 'ro', isa => 'Str');
  has IdentityProviderDetails => (is => 'ro', isa => 'Paws::Transfer::IdentityProviderDetails');
  has LoggingRole => (is => 'ro', isa => 'Str');
  has ServerId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateServer');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Transfer::UpdateServerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Transfer::UpdateServer - Arguments for method UpdateServer on L<Paws::Transfer>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateServer on the
L<AWS Transfer for SFTP|Paws::Transfer> service. Use the attributes of this class
as arguments to method UpdateServer.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateServer.

=head1 SYNOPSIS

    my $transfer = Paws->service('Transfer');
    my $UpdateServerResponse = $transfer->UpdateServer(
      ServerId        => 'MyServerId',
      EndpointDetails => {
        AddressAllocationIds => [ 'MyAddressAllocationId', ... ],    # OPTIONAL
        SubnetIds            => [ 'MySubnetId',            ... ],    # OPTIONAL
        VpcEndpointId => 'MyVpcEndpointId',    # min: 22, max: 22; OPTIONAL
        VpcId         => 'MyVpcId',            # OPTIONAL
      },    # OPTIONAL
      EndpointType            => 'PUBLIC',       # OPTIONAL
      HostKey                 => 'MyHostKey',    # OPTIONAL
      IdentityProviderDetails => {
        InvocationRole => 'MyRole',              # min: 20, max: 2048; OPTIONAL
        Url            => 'MyUrl',               # max: 255; OPTIONAL
      },    # OPTIONAL
      LoggingRole => 'MyNullableRole',    # OPTIONAL
    );

    # Results:
    my $ServerId = $UpdateServerResponse->ServerId;

    # Returns a L<Paws::Transfer::UpdateServerResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/transfer/UpdateServer>

=head1 ATTRIBUTES


=head2 EndpointDetails => L<Paws::Transfer::EndpointDetails>

The virtual private cloud (VPC) endpoint settings that are configured
for your SFTP server. With a VPC endpoint, you can restrict access to
your SFTP server to resources only within your VPC. To control incoming
internet traffic, you will need to associate one or more Elastic IP
addresses with your server's endpoint.



=head2 EndpointType => Str

The type of endpoint that you want your SFTP server to connect to. You
can choose to connect to the public internet or a virtual private cloud
(VPC) endpoint. With a VPC endpoint, your SFTP server isn't accessible
over the public internet.

Valid values are: C<"PUBLIC">, C<"VPC">, C<"VPC_ENDPOINT">

=head2 HostKey => Str

The RSA private key as generated by C<ssh-keygen -N "" -f
my-new-server-key>.

If you aren't planning to migrate existing users from an existing SFTP
server to a new AWS SFTP server, don't update the host key.
Accidentally changing a server's host key can be disruptive.

For more information, see
"https://docs.aws.amazon.com/transfer/latest/userguide/configuring-servers.html#change-host-key"
in the I<AWS SFTP User Guide.>



=head2 IdentityProviderDetails => L<Paws::Transfer::IdentityProviderDetails>

This response parameter is an array containing all of the information
required to call a customer's authentication API method.



=head2 LoggingRole => Str

A value that changes the AWS Identity and Access Management (IAM) role
that allows Amazon S3 events to be logged in Amazon CloudWatch, turning
logging on or off.



=head2 B<REQUIRED> ServerId => Str

A system-assigned unique identifier for an SFTP server instance that
the user account is assigned to.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateServer in L<Paws::Transfer>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

